@@ -355,9 +355,20 @@ linklabels<-function(text,tips,link.type=c("bent","curved","straight"),
 }
 
 ## function forces a tree to be ultrametric using two different methods
-## written by Liam J. Revell 2017
+## written by Liam J. Revell 2017, 2021
 
-force.ultrametric<-function(tree,method=c("nnls","extend")){
+force.ultrametric<-function(tree,method=c("nnls","extend"),...){
+	if(hasArg(message)) message<-list(...)$message
+	else message<-TRUE
+	if(message){
+		cat("***************************************************************\n")
+		cat("*                          Note:                              *\n")
+		cat("*    force.ultrametric does not include a formal method to    *\n")
+		cat("*    ultrametricize a tree & should only be used to coerce    *\n")
+		cat("*   a phylogeny that fails is.ultramtric due to rounding --   *\n")
+		cat("*    not as a substitute for formal rate-smoothing methods.   *\n")
+		cat("***************************************************************\n")
+	}
 	method<-method[1]
 	if(method=="nnls") tree<-nnls.tree(cophenetic(tree),tree,
 		rooted=TRUE,trace=0)
